ClusterLayoutVersionStatus

Enum ClusterLayoutVersionStatus 

pub enum ClusterLayoutVersionStatus {
    Current,
    Draining,
    Historical,
}

Variants



Current

This is the most up-to-date layout version



Draining

This version is still active in the cluster because metadata is being rebalanced or migrated from old nodes



Historical

This version is no longer active in the cluster for metadata reads and writes. Note that there is still the possibility that data blocks are being migrated away from nodes in this layout version.