pub struct ClusterLayoutSkipDeadNodesRequest {
pub version: u64,
pub allow_missing_data: bool,
}Fields
version: u64Version number of the layout to assume is currently up-to-date. This will generally be the current layout version.
allow_missing_data: boolAllow the skip even if a quorum of nodes could not be found for the data among the remaining nodes